/*
 * @(#)ServletGen
 *
 * Copyright (c) 1998 Karl Moss. All Rights Reserved.
 *
 * You may study, use, modify, and distribute this software for any
 * purpose provided that this copyright notice appears in all copies.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @version 1.0
 * @date    25Apr98
 *
 */

package javaservlets.CodeGen;

/**
  * <p>This application will invoke the proper code generator
  * depending upon the command line options given:
  *
  *  -i  Interface name
  *  -c  Class name
  *  -l  (option) Lite version
  *
  * All generated source will be created in the current directory.
  */

public class ServletGen
{
  public static void main(String args[])
    {
      // Get the interface name
      String interfaceName = getArg(args, "-i");

      // Get the class name
      String className = getArg(args, "-c");

      // Get the optional 'lite' arg
      boolean lite = argExists(args, "-l");

      // Make sure the required parameters were given
      if ((interfaceName == null) ||
          (className == null)) {
        System.out.println("\nServletGen usage:\n");
        System.out.println("ServletGen -i<interface> -c<class> " +
                           "[-l]");
        return;
      }

      try {

        // Generate the appropriate code
        if (lite) {
          
           // Generate the lite client
          ServletGenLiteClient client = new ServletGenLiteClient();
          client.setInterfaceName(interfaceName);
          client.setObjectName(className);
          System.out.println("Generating servlet client proxy");
          client.generate();
          
          // Generate the server
          ServletGenLiteServer server = new ServletGenLiteServer();
          server.setInterfaceName(interfaceName);
          server.setObjectName(className);
          System.out.println("Generating servlet server stub");
          server.generate();
        }
        else {
          
          // Generate the client
          ServletGenClient client = new ServletGenClient();
          client.setInterfaceName(interfaceName);
          client.setObjectName(className);
          System.out.println("Generating servlet client proxy");
          client.generate();
          
          // Generate the server
          ServletGenServer server = new ServletGenServer();
          server.setInterfaceName(interfaceName);
          server.setObjectName(className);
          System.out.println("Generating servlet server stub");
          server.generate();
          
        }
      }
      catch (Exception ex) {
        ex.printStackTrace();
      }
    }

  /**
    * <p>Find the given argument switch.
    *
    * @param args Array of command line arguments
    * @param s Switch to find
    * @return Value of the argument or null if not found
    */
  public static String getArg(String args[], String s)
    {
      String arg = null;

      if (args != null) {
        // Find the switch in the array
        for (int i = 0; i < args.length; i++) {

          // Does the switch match?
          if (args[i].startsWith(s)) {
            if (args[i].length() > s.length()) {

              // Get the value
              arg = args[i].substring(s.length());
              break;
            }
          }
        }
      }
      
      return arg;
    }

  /**
    * <p>Determines if the given argument switch exists.
    *
    * @param args Array of command line arguments
    * @param s Switch to find
    * @return true if the switch exists
    */
  public static boolean argExists(String args[], String s)
    {
      boolean rc = false;
      
      if (args != null) {
        // Find the switch in the array
        for (int i = 0; i < args.length; i++) {

          // Does the switch match?
          if (args[i].startsWith(s)) {
            rc = true;
            break;
          }
        }
      }
      
      return rc;
    }
  
}
